"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Overlay = Overlay;

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _reactNative = require("react-native");

var _hooks = require("../hooks");

var _focus = require("@react-native-aria/focus");

var _context = require("./context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Overlay(props) {
  let {
    isOpen,
    children,
    autoFocus = true,
    restoreFocus = true,
    trapFocus = true,
    onClose,
    isKeyboardDismissable = true,
    shouldCloseOnOutsideClick = true,
    focusable = true,
    animated = true,
    animationEntryDuration,
    animationExitDuration,
    overlayRef,
    triggerRef
  } = props;
  const {
    styles,
    isExited
  } = (0, _hooks.useAnimatedStyles)({
    animated,
    animationEntryDuration,
    animationExitDuration,
    isOpen
  });
  (0, _hooks.useKeyboardDismissable)({
    enabled: isKeyboardDismissable,
    onClose: onClose ? onClose : () => {}
  });
  (0, _hooks.useCloseOnOutsideClick)({
    refs: [overlayRef, triggerRef],
    enabled: shouldCloseOnOutsideClick,
    onClose: onClose ? onClose : () => {}
  });

  if (!isOpen && isExited) {
    return null;
  }

  let content = /*#__PURE__*/_react.default.createElement(_context.OverlayContext.Provider, {
    value: {
      onClose
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [_reactNative.StyleSheet.absoluteFill, styles],
    pointerEvents: "box-none"
  }, focusable ? /*#__PURE__*/_react.default.createElement(_focus.FocusScope, {
    contain: trapFocus,
    autoFocus: autoFocus,
    restoreFocus: restoreFocus
  }, children) : children));

  return /*#__PURE__*/_reactDom.default.createPortal(content, document.body);
}
//# sourceMappingURL=Overlay.web.js.map