"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tooltip = void 0;

var _react = _interopRequireDefault(require("react"));

var _Overlay = require("../Overlay/Overlay");

var _hooks = require("../hooks");

var _Popper = require("../Popper/Popper");

var _OverlayBackdrop = require("../Overlay/OverlayBackdrop");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

// Tooltip's code is almost same as Popover with some exceptions. Defaults to on="hover"
// and focusable=false and also has different ARIA attributes via useTooltip hook.
const Tooltip = props => {
  let triggerRef = _react.default.useRef(null);

  const [isOpen, setIsOpen] = (0, _hooks.useControllableState)({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  let triggerElem = null; // Received a trigger ref

  if (props.trigger.hasOwnProperty('current')) {
    // @ts-ignore
    triggerRef = props.trigger;
  } // Received a trigger element
  else if ( /*#__PURE__*/_react.default.isValidElement(props.trigger)) {
      var _props$on;

      const triggerExistingProps = props.trigger.props; // Trigger won't be changes in rerenders, so this seems safe
      // eslint-disable-next-line react-hooks/rules-of-hooks

      const handlers = (0, _hooks.useOn)({
        on: (_props$on = props.on) !== null && _props$on !== void 0 ? _props$on : 'hover',
        onClose: handleClose,
        onOpen: handleOpen,
        ...triggerExistingProps
      });
      triggerElem = /*#__PURE__*/_react.default.cloneElement(props.trigger, {
        ref: triggerRef,
        ...handlers
      });
    } else {
      console.warn(`Tooltip: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
    }

  const {
    triggerProps,
    contentProps
  } = (0, _hooks.useTooltip)({
    isOpen
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/_react.default.cloneElement(triggerElem, { ...triggerProps
    });
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, triggerElem, /*#__PURE__*/_react.default.createElement(_Overlay.Overlay, {
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    focusable: false,
    animated: props.animated,
    animationEntryDuration: props.animationEntryDuration,
    animationExitDuration: props.animationExitDuration
  }, /*#__PURE__*/_react.default.createElement(_Popper.Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps
  }))));
};

exports.Tooltip = Tooltip;
Tooltip.Content = _Popper.Popper.Content;
Tooltip.Arrow = _Popper.Popper.Arrow;
Tooltip.Backdrop = _OverlayBackdrop.OverlayBackdrop;
//# sourceMappingURL=index.js.map