function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { Overlay } from '../Overlay/Overlay';
import { useControllableState, useOn, useTooltip } from '../hooks';
import { Popper } from '../Popper/Popper';
import { OverlayBackdrop } from '../Overlay/OverlayBackdrop'; // Tooltip's code is almost same as Popover with some exceptions. Defaults to on="hover"
// and focusable=false and also has different ARIA attributes via useTooltip hook.

const Tooltip = props => {
  let triggerRef = React.useRef(null);
  const [isOpen, setIsOpen] = useControllableState({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  let triggerElem = null; // Received a trigger ref

  if (props.trigger.hasOwnProperty('current')) {
    // @ts-ignore
    triggerRef = props.trigger;
  } // Received a trigger element
  else if ( /*#__PURE__*/React.isValidElement(props.trigger)) {
      var _props$on;

      const triggerExistingProps = props.trigger.props; // Trigger won't be changes in rerenders, so this seems safe
      // eslint-disable-next-line react-hooks/rules-of-hooks

      const handlers = useOn({
        on: (_props$on = props.on) !== null && _props$on !== void 0 ? _props$on : 'hover',
        onClose: handleClose,
        onOpen: handleOpen,
        ...triggerExistingProps
      });
      triggerElem = /*#__PURE__*/React.cloneElement(props.trigger, {
        ref: triggerRef,
        ...handlers
      });
    } else {
      console.warn(`Tooltip: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
    }

  const {
    triggerProps,
    contentProps
  } = useTooltip({
    isOpen
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/React.cloneElement(triggerElem, { ...triggerProps
    });
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, triggerElem, /*#__PURE__*/React.createElement(Overlay, {
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    focusable: false,
    animated: props.animated,
    animationEntryDuration: props.animationEntryDuration,
    animationExitDuration: props.animationExitDuration
  }, /*#__PURE__*/React.createElement(Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps
  }))));
};

Tooltip.Content = Popper.Content;
Tooltip.Arrow = Popper.Arrow;
Tooltip.Backdrop = OverlayBackdrop;
export { Tooltip };
//# sourceMappingURL=index.js.map